Ethereal

[Ethereal-dev] New protocol WBXML
Google
 
Web Ethereal.com

Home | Introduction | Documentation | Lists | FAQ | Development | Wiki | Bugs

Ethereal-dev: February 2003


Hi all,

Please find a first attempt at WBXML content decoding. Currently only WBXML
header decoding is supported.

Add packet-wbxml.c and packet-wbxml.h to Makefile.am.
Apply the following patch to packet-wsp.c:

============================================================================
====
$ diff -u ethereal-2003-02-04/packet-wsp.c ethereal/packet-wsp.c
--- ethereal-2003-02-04/packet-wsp.c    2002-09-25 02:01:18.000000000 +0200
+++ ethereal/packet-wsp.c 2003-02-05 19:48:33.000000000 +0100
@@ -4919,9 +4919,9 @@
 proto_reg_handoff_wsp(void)
 {
        /*
         * Get a handle for the WMLC dissector.
         */
-       wmlc_handle = find_dissector("wmlc");   /* Coming soon :) */
+       wmlc_handle = find_dissector("wbxml");

        /*
         * And get a handle for the WTP-over-UDP dissector.
@@ -4919,9 +4919,9 @@
 {
        /*
-        * Get a handle for the WMLC dissector.
+        * Get a handle for the WBXML dissector.
         */
============================================================================
====

Please check in. Comments are welcome :)

Regards,

  Olivier Biot                     Siemens ATEA IC D MS C
O-------------------------------o-------------------------------O
| Phone   : +32  (14) 25 39 84  |  Address: Atealaan 34         |
| Fax     : +32  (14) 22 29 94  |           2200 Herentals      |
| Cellular: +32 (474) 96 32 09  |           Belgium             |
O-------------------------------o-------------------------------O
~  "I love deadlines.  I especially love the swooshing sound    ~
~   they make as they go flying by."               - Dilbert    ~

Attachment: packet-wbxml.h
Description: Binary data

Attachment: packet-wbxml.c
Description: Binary data


Powered by MHonArc 2.6.10